@@ -119,11 +119,12 @@ mysql_ur_string_lookup = """(SELECT GROUP_CONCAT(buckeyebrowser_segmenttype.Labe
                                     =buckeyebrowser_wordtype.id) REGEXP %s"""
 
 pg_ur_string_lookup = """array_to_string
-                            (
-                            ARRAY (
-                                    SELECT st.Label
-                                    FROM buckeyebrowser_underlying ur, buckeyebrowser_segmenttype st
-                                    WHERE st.id = ur.SegmentType_id
-                                    AND ur.WordType_id = buckeyebrowser_wordtype.id
-                                    )
-                            ) ~ %s"""
+                                        (
+                                        ARRAY (
+                                                SELECT st."Label"
+                                                FROM buckeyebrowser_underlying ur, buckeyebrowser_segmenttype st
+                                                WHERE st.id = ur."SegmentType_id"
+                                                AND ur."WordType_id" = buckeyebrowser_wordtype.id
+                                                ),
+                                        ' '
+                                        ) ~ %s"""
