@@ -481,8 +481,9 @@ class WordType(caching.base.CachingMixin,models.Model):
         neighs = WordType.objects.filter(Label__regex="^[^{<]").extra(
                     where = [UR_LOOKUP],
                     params = ['|'.join(patterns)])
-        nd = len(neighs)
-        fwnd = sum([ x.getFreq(subset=subset,speaker=speaker,dialog=dialog) for x in neighs])
+        freqs = [ x.getFreq(subset=subset,speaker=speaker,dialog=dialog) for x in neighs]
+        nd = sum([1 for x in freqs if x > 0])
+        fwnd = sum(freqs)
         if subset == 'all':
             self.ND,self.FWND = nd,fwnd
             self.save()
